# ExperimentTracker
Simple tool to track experiments by writing parameters and corresponding results into an SQL database.

## Install
`pip install experiment-tracker`

## How to use
A simple example can be found in the file [example.py](https://github.com/MarkusZopf/ExperimentTracker/blob/master/example.py).
